@@ -9,7 +9,7 @@ sys.path.insert(0, path)
 
 # Not correct, but enough to get the tests going uninstalled
 builtins.__dict__['DATADIR'] = path
-builtins.__dict__['GIRDIR'] = ''
+builtins.__dict__['GIR_DIR'] = path
 
 from giscanner.annotationparser import GtkDocCommentBlockParser
 from giscanner.ast import Include, Namespace
@@ -78,7 +78,7 @@ def _diff(a, b):
 
 
 def _extract_expected(filename):
-    fd = open(filename, 'r')
+    fd = open(filename, 'r', encoding='utf-8')
     data = fd.read()
     fd.close()
 
